<?php

declare(strict_types=1);

namespace Dedi\SyliusImportExportPlugin\Formater;

use Doctrine\Common\Collections\Collection;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Serializer\Encoder\CsvEncoder;
use Symfony\Component\Serializer\Encoder\EncoderInterface;

class CsvFormater implements FormaterInterface
{
    protected EncoderInterface $encoder;

    public function __construct(EncoderInterface $encoder)
    {
        $this->encoder = $encoder;
    }

    public function format(Collection $data): string
    {
        return $this->encoder->encode($data->toArray(), 'csv', [CsvEncoder::DELIMITER_KEY => ';']);
    }

    public function output(string $output, string $filename): Response
    {
        $response = new Response();
        $response->headers->set('Content-type', 'text/csv');
        $response->headers->set('Cache-Control', 'private');
        $response->headers->set('Content-Disposition', 'attachment; filename="' . $filename . '.csv";');
        $response->sendHeaders();
        $response->setContent($output);

        return $response;
    }

    public function getType(): string
    {
        return 'csv';
    }
}
