<?php

declare(strict_types=1);

namespace Dedi\SyliusImportExportPlugin\Formater;

use Doctrine\Common\Collections\Collection;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Serializer\Encoder\CsvEncoder;
use Symfony\Component\Serializer\Encoder\EncoderInterface;

class TxtFormater implements FormaterInterface
{
    private readonly string $delimiter;

    private readonly ?string $enclosure;

    private readonly EncoderInterface $encoder;

    public function __construct(EncoderInterface $encoder, string $delimiter = '|', ?string $enclosure = '"')
    {
        $this->encoder = $encoder;
        $this->delimiter = $delimiter;
        $this->enclosure = $enclosure;
    }

    public function format(Collection $data): string
    {
        return $this->encoder->encode(
            $data->toArray(),
            'csv',
            [CsvEncoder::DELIMITER_KEY => $this->delimiter, CsvEncoder::ENCLOSURE_KEY => $this->enclosure],
        );
    }

    public function output(string $output, string $filename): Response
    {
        $response = new Response();
        $response->headers->set('Content-type', 'text/plain');
        $response->headers->set('Cache-Control', 'private');
        $response->headers->set('Content-Disposition', 'attachment; filename="' . $filename . '.txt";');
        $response->sendHeaders();
        $response->setContent($output);

        return $response;
    }

    public function getType(): string
    {
        return 'txt';
    }
}
