<?php

namespace Tests\Dedi\SyliusImportExportPlugin\Application\src\Processor;

use Doctrine\ORM\EntityManagerInterface;
use FriendsOfSylius\SyliusImportExportPlugin\Exception\ImporterException;
use FriendsOfSylius\SyliusImportExportPlugin\Processor\MetadataValidatorInterface;
use FriendsOfSylius\SyliusImportExportPlugin\Processor\ResourceProcessorInterface;
use Sylius\Component\Core\Model\ProductInterface;
use Sylius\Component\Core\Repository\ProductRepositoryInterface;

class DummyProcessor implements ResourceProcessorInterface
{
    private readonly MetadataValidatorInterface $metadataValidator;

    private readonly EntityManagerInterface $entityManager;

    private readonly ProductRepositoryInterface $repository;

    public function __construct(
        MetadataValidatorInterface $metadataValidator,
        EntityManagerInterface $entityManager,
        ProductRepositoryInterface $repository
    ) {
        $this->metadataValidator = $metadataValidator;
        $this->entityManager = $entityManager;
        $this->repository = $repository;
    }

    /**
     * @throws ImporterException
     */
    public function process(array $data): void
    {
        $headers = ['code', 'name'];

        $this->metadataValidator->validateHeaders($headers, $data);

        $data = array_combine($headers, $data);

        $taxon = $this->getProduct($data);
        $this->entityManager->persist($taxon);
    }

    protected function getProduct(array $data): ProductInterface
    {
        /** @var ?ProductInterface $product */
        $product = $this->repository->findOneBy(['code' => $data['code']]);

        if (null === $product) {
            throw new ImporterException(sprintf('Product with code %s does not exist', $data['code']));
        }

        $product->setName($data['name']);

        return $product;
    }
}
